@@ -14,12 +14,11 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Settings
- * @version    $Id: 220.ftpserver.php 1 2010-04-07 10:00:00Z monotek $
+ *
  */
-
 return array(
 	'groups' => array(
-	'ftpserver' => array(
+		'ftpserver' => array(
 			'title' => $lng['admin']['ftpserversettings'],
 			'fields' => array(
 				'ftpserver' => array(
@@ -29,11 +28,14 @@ return array(
 					'type' => 'option',
 					'default' => 'proftpd',
 					'option_mode' => 'one',
-					'option_options' => array('proftpd' => 'Proftpd', 'pureftpd' => 'Pureftpd'),
-					'save_method' => 'storeSettingField',
-				),
-			),
-		),
+					'option_options' => array(
+						'proftpd' => 'Proftpd',
+						'pureftpd' => 'Pureftpd'
+					),
+					'save_method' => 'storeSettingField'
+				)
+			)
+		)
 	)
 );
 
